==> haskell-hspec-2.8.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec
version:              2.8.1
visibility:           public
id:                   hspec-2.8.1-4rXe6lWUwcmGFIHgl211Wp
key:                  hspec-2.8.1-4rXe6lWUwcmGFIHgl211Wp
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <http://hspec.github.io/>.

category:             Testing
abi:                  b83fb0c67a901cf22689ba92759f493e
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hspec-2.8.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hspec-2.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hspec-2.8.1
hs-libraries:         HShspec-2.8.1-4rXe6lWUwcmGFIHgl211Wp
depends:
    QuickCheck-2.14.2-1Bekdcpaoco52kkbfPlodE base-4.14.1.0
    hspec-core-2.8.1-6QSPJrODOrRC2Pc4h1wFWs
    hspec-discover-2.8.1-Da9A7YgRK5QLvZw0iVyHyr
    hspec-expectations-0.8.2-4T2sv1DBBhWKyVScectlCn

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.8.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec
version:              2.8.2
visibility:           public
id:                   hspec-2.8.2-4ZYpQa9VCwv56bOV9RusVv
key:                  hspec-2.8.2-4ZYpQa9VCwv56bOV9RusVv
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <http://hspec.github.io/>.

category:             Testing
abi:                  f8c7ef50ac0cab6fc02242e1d36d9100
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hspec-2.8.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hspec-2.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hspec-2.8.2
hs-libraries:         HShspec-2.8.2-4ZYpQa9VCwv56bOV9RusVv
depends:
    QuickCheck-2.14.2-JBdTpAobWwg19WOWKtgrIg base-4.14.1.0
    hspec-core-2.8.2-7sSgwoOfonqBEko12UawtI
    hspec-discover-2.8.2-Kvw53qEJXoKJsZoqzaJpjm
    hspec-expectations-0.8.2-4T2sv1DBBhWKyVScectlCn

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
